==> polygonmeshtools-0.43.tar.gz: polygonmeshtools-0.43/polygonmeshtools/test_plot.py <==
import numpy as np
import matplotlib.pyplot as plt
import pytest

from .plot import plot_circular_fidi_mesh, plot_poly_fidi_mesh

def test_plot_circular_fidi_mesh():
    # Testing default conditions
    plot_circular_fidi_mesh(diameter=30)

    # Hiding axes
    plot_circular_fidi_mesh(diameter=10, show_axes=False)

    # Hiding title
    plot_circular_fidi_mesh(diameter=10, show_title=False)

    # centre_mesh = False
    plot_circular_fidi_mesh(diameter=30, centre_mesh=False)

    # incorrect value for centre_mesh
    with pytest.raises(ValueError):
        plot_circular_fidi_mesh(diameter=10, centre_mesh='test')
    
def test_plot_poly_fidi_mesh():
    # Default conditions
    for n in range(3,8):
        plot_poly_fidi_mesh(diameter=20, n=n)

    # Hiding axes
    plot_poly_fidi_mesh(diameter=20, n=3, show_axes=False)

    # Hiding title
    plot_poly_fidi_mesh(diameter=20, n=3, show_title=False)

    # centre_mesh = 'auto', decision-making
    plot_poly_fidi_mesh(diameter=30, x_spacing=3, y_spacing=3, n=6, centre_mesh='auto')
    # Above test inexplicably fails to satisfy the following:
    # (diameter % (2*x_spacing) == 0) and (diameter % (2*y_spacing) == 0)
    # Assuming bug in coverage.py...
    plot_poly_fidi_mesh(diameter=30, x_spacing=3, y_spacing=4, n=5, centre_mesh='auto')
    

    # centre_mesh = False
    plot_poly_fidi_mesh(diameter=30, n=5, centre_mesh=False)
    # incorrect value for centre_mesh
    with pytest.raises(ValueError):
        plot_poly_fidi_mesh(diameter=10, n=3, centre_mesh='test')

==> polygonmeshtools-0.45.tar.gz: polygonmeshtools-0.45/polygonmeshtools/test_plot.py <==
import numpy as np
import matplotlib.pyplot as plt
import pytest

from .plot import plot_circular_fidi_mesh, plot_poly_fidi_mesh


def test_plot_circular_fidi_mesh():
    # Testing default conditions
    plot_circular_fidi_mesh(diameter=30)

    # Hiding axes
    plot_circular_fidi_mesh(diameter=10, show_axes=False)

    # Hiding title
    plot_circular_fidi_mesh(diameter=10, show_title=False)

    # centre_mesh = False
    plot_circular_fidi_mesh(diameter=30, centre_mesh=False)

    # incorrect value for centre_mesh
    with pytest.raises(ValueError):
        plot_circular_fidi_mesh(diameter=10, centre_mesh='test')


def test_plot_poly_fidi_mesh():
    # Default conditions
    for n in range(3, 8):
        plot_poly_fidi_mesh(diameter=20, n=n)

    # Hiding axes
    plot_poly_fidi_mesh(diameter=20, n=3, show_axes=False)

    # Hiding title
    plot_poly_fidi_mesh(diameter=20, n=3, show_title=False)

    # centre_mesh = 'auto', decision-making
    plot_poly_fidi_mesh(
        diameter=30, x_spacing=3, y_spacing=3, n=6, centre_mesh='auto'
    )
    # Above test inexplicably fails to satisfy the following:
    # (diameter % (2*x_spacing) == 0) and (diameter % (2*y_spacing) == 0)
    # Assuming bug in coverage.py...
    plot_poly_fidi_mesh(
        diameter=30, x_spacing=3, y_spacing=4, n=5, centre_mesh='auto'
    )

    # centre_mesh = False
    plot_poly_fidi_mesh(diameter=30, n=5, centre_mesh=False)
    # Incorrect value for centre_mesh
    with pytest.raises(ValueError):
        plot_poly_fidi_mesh(diameter=10, n=3, centre_mesh='test')
